@@ -56,14 +56,13 @@ class QueryableMixin(object):
     @classmethod
     def unique_constraints(cls):
         return [
-            c for c in cls.constraints() 
+            c for c in cls.constraints()
             if isinstance(c, UniqueConstraint)]
 
     @classmethod
     def unique_constraint_col_name_tuples(cls):
         return [c.columns.keys() for c in cls.unique_constraints()]
 
-
     @classmethod
     def primary_key_name(cls):
         return cls.__mapper__.primary_key[0].key
@@ -90,7 +89,6 @@ class QueryableMixin(object):
             if r.key == attr)
         return mapped_rel.mapper.class_
 
-
     def update_without_commit(self, **kwargs):
         cls = type(self)
         kwargs = cls.pre_save_adapter(kwargs, existing_instance=self)
@@ -198,7 +196,8 @@ class QueryableMixin(object):
                     elif isinstance(val, dict):
                         rel_cls = cls.mapped_rel_class(attr)
                         mapping_col = rel.collection_class().keyfunc.name
-                        list_of_kwargs = [merge(v, {mapping_col: k}) for k, v in val.items()]
+                        list_of_kwargs = [
+                            merge(v, {mapping_col: k}) for k, v in val.items()]
                         kwargs[attr] = {getattr(obj, mapping_col): obj for obj in rel_cls.update_or_new_all(
                             list_of_kwargs=list_of_kwargs)}
                 elif isinstance(val, dict):
@@ -567,10 +566,10 @@ class QueryableMixin(object):
 
         # We need the results in the same order as the input keyvals
         # So order by field in SQL
-        key_result_mapping = {getattr(result, key): result for result in resultset.all()}
+        key_result_mapping = {
+            getattr(result, key): result for result in resultset.all()}
         return [key_result_mapping.get(kv) for kv in original_keyvals]
 
-
     @classmethod
     def get_or_404(cls, id):
         """Same as Flask-SQLAlchemy's `get_or_404`.
@@ -664,17 +663,20 @@ class QueryableMixin(object):
     def get_matching_obj_using_unique_keys(cls, kwargs):
         primary_key_name = cls.primary_key_name()
         if primary_key_name in kwargs:
-            obj = cls.first(**subdict(kwargs, primary_key_name))
+            matching_data = subdict(kwargs, [primary_key_name])
+            obj = cls.first(**matching_data) if matching_data else None
             if obj:
                 return obj
         for k in cls.unique_column_names():
-            if k in kwargs and k!=primary_key_name:
-                obj = cls.first(**subdict(kwargs, k))
+            if k in kwargs and k != primary_key_name:
+                matching_data = subdict(kwargs, [k])
+                obj = cls.first(**matching_data) if matching_data else None
                 if obj:
                     return obj
         for col_name_tuple in cls.unique_constraint_col_name_tuples():
             if all(c in kwargs for c in col_name_tuple):
-                obj = cls.first(**subdict(kwargs, col_name_tuple))
+                matching_data = subdict(kwargs, col_name_tuple)
+                obj = cls.first(**matching_data) if matching_data else None
                 if obj:
                     return obj
         return None
@@ -694,7 +696,7 @@ class QueryableMixin(object):
     @classmethod
     def update_or_new(cls, **kwargs):
         keys = kwargs.pop('keys') if 'keys' in kwargs else []
-        if keys is None or len(keys)==0:
+        if keys is None or len(keys) == 0:
             return cls.update_matching_obj_or_generate_new_obj(kwargs)
         return cls.get_updated_or_new_obj(kwargs, keys)
 
@@ -1036,4 +1038,4 @@ class QueryableMixin(object):
 
     @classmethod
     def buckets(cls, bucket_size=None):
-    	return cls.query.buckets(bucket_size=bucket_size)
\ No newline at end of file
+        return cls.query.buckets(bucket_size=bucket_size)
